# Open Source Download Link 

## Relase From Pypi


# Information 

## Proper nouns 
Kinetics Artifactual Navy Self-fegulative En-lore Node -> KANSEN -> 舰船（艦船）
動力学人工海上作戦機構·自律行動型伝承接続端子 -> 动力学人工海上作战机构·自律行动型历史连接端子 

# Copyright Information 

## LICENSE 
> Copyright (C) 2021 - 2022 Matt Belfast Brown  
>   
> This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.  
>    
> This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.  
>   
> You should have received a copy of the GNU General Public License along with this program.  If not, see <https://www.gnu.org/licenses/> .  

## Author and Version  
### Author Information  
> Author: ***Matt Belfast Brown*** or *Matt Brown* or *M.B.B.*（ **Name in English** ）  
>> Also be called ***The Day of The Doctor*** ( **Network Nickname** )  
>> ***鈴木夢美*** or ***伊藤京介*** ( **Name in Japanese** )  
>> ***沈永基***，***皓月***，***飞瀑山人***，***衍枫阁主人*** ( **Name in Chinese, Style Name, Pseudonym, Alias** ) 
    
### Contact Details 
> E-mail: ***thedayofthedo@gmail.com*** or ***thedayofthedoctor@foxmail.com***   
> TEL:\+86-15841486187 
>  
> Address: **Room 313, Apartment No. 14, South District, South Campus, Northwest A&F University, No. 22, Xinong Road, Litai Street, Yangling District, Shaanxi Province, China**  
> Address: ***中国陕西省杨凌区李台街道西农路22号西北农林科技大学南校区南区14号公寓313宿舍***  
   
### Version:  
> First Edition Time: 2021-07-10  
> Last Revision Time: 2022-02-16  
> Version Number: 0.5.1  
> 
> **Version Update Log:**  
>> #### 0.5.1  
>> + 更新ReadME文档  
>> + 使用PyCharm进行代码体系更新
>> + 从AzurLaneFleetTool(**author: x94fujo6rpg**)改编新增`mode_FLE_Tol.py`
